@@ -18,7 +18,10 @@ class DotArray {
     public function fromArray($array) {
         $this->array = $array;
     }
-    public function toDot() {
-        return Dot::fromArray($this->array);
+    public function parse($separator='.') {
+        Dot::parse($this->array,$separator);
+    }
+    public function __toString() {
+        return json_encode($this->array);
     }
 }
\ No newline at end of file
